@@ -4,7 +4,7 @@ import astropy.coordinates
 import pytest
 
 from antares_client import search
-from antares_client._api.models import Locus
+from antares_client.models import Locus
 from antares_client.exceptions import AntaresException
 
 
